import { Decimal } from 'decimal.js';

class InvoiceItem {
	/**
	 * 创建一个新的收据项目实体。
	 * @param id 收据项目的 ID。
	 * @param description 项目的名称/描述。
	 * @param quantity 项目的数量。
	 * @param unit 项目的单位。
	 * @param unitPrice 项目的单价。
	 */
	constructor(id: number, description: string, quantity: number, unit: string, unitPrice: Decimal) {
		this.id = id
		this.description = description
		this.quantity = quantity
		this.unit = unit
		this.unitPrice = unitPrice
	} 

	/**
	 * 收据项目的 ID。
	 */
	id: number

	/**
	 * 项目的名称/描述。
	 */
	description?: string

	/**
	 * 项目的数量。
	 */
	quantity?: number

	/**
	 * 项目的单位。
	 */
	unit?: string

	/**
	 * 项目的单价。
	 */
	unitPrice?: Decimal

	/**
	 * 获取项目的小计。
	 */
	getSubtotal() {
		if (!this.quantity || !this.unitPrice) return 0
		return this.quantity * this.unitPrice.toNumber()
	}
}

export default InvoiceItem